==> express-engine-video-0.11.0-sources.jar: im/zego/zegoexpress/callback/IZegoCustomVideoRenderHandler.java <==
package im.zego.zegoexpress.callback;

import im.zego.zegoexpress.constants.*;
import im.zego.zegoexpress.callback.*;
import im.zego.zegoexpress.entity.*;
import java.nio.*;
import java.util.*;
import org.json.*;
import im.zego.zegoexpress.*;
import android.app.Application;
import android.graphics.*;

public abstract class IZegoCustomVideoRenderHandler {

    /**
     * The callback for obtaining the locally captured video frames (Raw Data).
     *
     * @param data Raw data of video frames (eg: RGBA only needs to consider data[0], I420 needs to consider data[0,1,2])
     * @param dataLength Data length (eg: RGBA only needs to consider dataLength[0], I420 needs to consider dataLength[0,1,2])
     * @param param Video frame parameters
     * @param flipMode video flip mode
     * @param channel Publishing stream channel
     */
    public void onCapturedVideoFrameRawData(ByteBuffer[] data, int[] dataLength, ZegoVideoFrameParam param, ZegoVideoFlipMode flipMode, ZegoPublishChannel channel){

    }

    /**
     * The callback for obtaining the video frames (Raw Data) of the remote stream. Different streams can be identified by streamID.
     *
     * @param data Raw data of video frames (eg: RGBA only needs to consider data[0], I420 needs to consider data[0,1,2])
     * @param dataLength Data length (eg: RGBA only needs to consider dataLength[0], I420 needs to consider dataLength[0,1,2])
     * @param param Video frame parameters
     * @param streamID Stream ID
     */
    public void onRemoteVideoFrameRawData(ByteBuffer[] data, int[] dataLength, ZegoVideoFrameParam param, String streamID){

    }

    /**
     * The callback for obtianing the video frames (Encoded Data) of the remote stream. Different streams can be identified by streamID.
     *
     * @param data Encoded data of video frames
     * @param dataLength Data length
     * @param param Video frame parameters
     * @param referenceTimeMillisecond video frame reference time
     * @param streamID Stream ID
     */
    public void onRemoteVideoFrameEncodedData(ByteBuffer data, int dataLength, ZegoVideoEncodedFrameParam param, long referenceTimeMillisecond, String streamID){

    }

}

==> express-engine-video-1.7.8-sources.jar: im/zego/zegoexpress/callback/IZegoCustomVideoRenderHandler.java <==
package im.zego.zegoexpress.callback;

import im.zego.zegoexpress.constants.*;
import im.zego.zegoexpress.callback.*;
import im.zego.zegoexpress.entity.*;
import java.nio.*;
import java.util.*;
import org.json.*;
import im.zego.zegoexpress.*;
import android.app.Application;
import android.graphics.*;

public abstract class IZegoCustomVideoRenderHandler {

    /**
     * Local preview video frame raw data callback
     *
     * @param data Raw data of video frames (eg: RGBA only needs to consider data[0], I420 needs to consider data[0,1,2])
     * @param dataLength Data length (eg: RGBA only needs to consider dataLength[0], I420 needs to consider dataLength[0,1,2])
     * @param param Video frame parameters
     * @param flipMode video flip mode
     * @param channel Publishing stream channel.
     */
    public void onCapturedVideoFrameRawData(ByteBuffer[] data, int[] dataLength, ZegoVideoFrameParam param, ZegoVideoFlipMode flipMode, ZegoPublishChannel channel){

    }

    /**
     * Remote playing stream video frame raw data callback, you can differentiate different streams by streamID
     *
     * @param data Raw data of video frames (eg: RGBA only needs to consider data[0], I420 needs to consider data[0,1,2])
     * @param dataLength Data length (eg: RGBA only needs to consider dataLength[0], I420 needs to consider dataLength[0,1,2])
     * @param param Video frame parameters
     * @param streamID Stream ID
     */
    public void onRemoteVideoFrameRawData(ByteBuffer[] data, int[] dataLength, ZegoVideoFrameParam param, String streamID){

    }

}
